/**
 * Copyright (c) 2003-2004, Mark Lussier
 * All rights reserved.
 *
 * Portions Copyright (c) 2003 by David A. Czarnecki
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 *      this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright notice,
 *      this list of conditions and the following disclaimer in the documentation
 *      and/or other materials provided with the distribution.
 * Neither the name of the "Mark Lussier" and "Sandler" nor the names of
 * its contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Products derived from this software may not be called "Sandler",
 * nor may "Sandler" appear in their name, without prior written permission of
 * Mark Lussier
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.intabulas.sandler.api.impl;

import org.intabulas.sandler.api.SearchResults;
import org.intabulas.sandler.elements.AtomElement;
import org.intabulas.sandler.elements.Entry;

import java.util.ArrayList;
import java.util.List;

/**
 * SearchResults
 * 
 * @author Mark Lussier
 * @version $Id: SearchResultsImpl.java,v 1.2 2004/01/02 01:43:57 intabulas Exp $
 */
public class SearchResultsImpl implements SearchResults, AtomElement {

    private List _entryList;

    public SearchResultsImpl() {
        _entryList = new ArrayList(1);
    }


    /**
     * @return 
     */
    public int getEntryCount() {
        return _entryList.size();
    }

    /**
     * @param index 
     * 
     * @return 
     */
    public Entry getEntry(int index) {
        Entry result = null;
        if (index >= 0 && index < _entryList.size()) {
            result = (Entry) _entryList.get(index);
        }
        return result;
    }

    /**
     * @param entry 
     */
    public boolean addEntry(Entry entry) {
        return _entryList.add(entry);
    }

    /**
     * @param index 
     * @param entry 
     */
    public void addEntry(int index, Entry entry) {
        _entryList.add(index, entry);
    }


    /**
     * Returns a string representation of the object.
     * 
     * @return a string representation of the object.
     */
    public String toString() {
        StringBuffer buffer = new StringBuffer(HTMLTAG_START).append(ELEMENT_SEARCHRESULTS).append(" xmlns=");
        buffer.append(ATOM_NAMESPACE).append(HTMLTAG_CLOSE);


        if (_entryList.size() > 0) {
            for (int x = 0; x < _entryList.size(); x++) {
                Entry entry = (Entry) _entryList.get(x);
                buffer.append(entry.toString());
            }

        }

        buffer.append(HTMLTAG_BEGIN).append(ELEMENT_SEARCHRESULTS).append(HTMLTAG_CLOSE);

        return buffer.toString();
    }
}
